diff --git a/src/System.Management.Automation/FormatAndOutput/common/FormatViewGenerator_Table.cs b/src/System.Management.Automation/FormatAndOutput/common/FormatViewGenerator_Table.cs
index 3b14c0754ba..27f58f65f94 100644
--- a/src/System.Management.Automation/FormatAndOutput/common/FormatViewGenerator_Table.cs
+++ b/src/System.Management.Automation/FormatAndOutput/common/FormatViewGenerator_Table.cs
@@ -129,7 +129,7 @@ internal override FormatStartData GenerateStartData(PSObject so)
///
/// Limits the association list size for table view.
/// For v1.0, table view supports only 10 properties.
///
/// The list to limit.
/// The limited list.
@@ -137,7 +137,8 @@ private static List LimitAssociationL
List list)
{
// NOTE: this is an arbitrary number, chosen to be a sensitive default
- const int maxCount = 10;
+ // In future we will most likely extract this from $PSStyle & most likely from $PSStyle.FormatTable.MaxColumns
+ const int maxCount = 30;
if (list.Count <= maxCount)
{
@@ -129,7 +129,7 @@ internal override FormatStartData GenerateStartData(PSObject so)
///
/// Limits the association list size for table view.
- /// For v1.0, table view supports only 10 properties.
+ /// For v1.1 table view supports only 30 properties.
///
/// The list to limit.